Module hash_map

Module hash_map 

[std ::collections ::HashMap] macros

Macros

hmap
Creates a HashMap from a list of key-value pairs.
into_hmap
Creates a HashMap from a list of key-value pairs.

Structs

DefaultHasher
The default Hasher used by RandomState.
Drain
A draining iterator over the entries of a HashMap.
ExtractIf
A draining, filtering iterator over the entries of a HashMap.
HashMap
A hash map implemented with quadratic probing and SIMD lookup.
IntoIter
An owning iterator over the entries of a HashMap.
IntoKeys
An owning iterator over the keys of a HashMap.
IntoValues
An owning iterator over the values of a HashMap.
Iter
An iterator over the entries of a HashMap.
IterMut
A mutable iterator over the entries of a HashMap.
Keys
An iterator over the keys of a HashMap.
OccupiedEntry
A view into an occupied entry in a HashMap. It is part of the Entry enum.
RandomState
RandomState is the default state for HashMap types.
VacantEntry
A view into a vacant entry in a HashMap. It is part of the Entry enum.
Values
An iterator over the values of a HashMap.
ValuesMut
A mutable iterator over the values of a HashMap.
OccupiedErrorExperimental
The error returned by try_insert when the key already exists.

Enums

Entry
A view into a single entry in a map, which may either be vacant or occupied.