Module vec_deque

Module vec_deque 

[std ::collections ::VecDeque] macros

Macros

deque
Creates a VecDeque from a list of elements.
into_vecd
Creates a VecDeque from a list of elements.

Structs

Drain
A draining iterator over the elements of a VecDeque.
IntoIter
An owning iterator over the elements of a VecDeque.
Iter
An iterator over the elements of a VecDeque.
IterMut
A mutable iterator over the elements of a VecDeque.
VecDeque
A double-ended queue implemented with a growable ring buffer.
ExtractIfExperimental
An iterator which uses a closure to determine if an element should be removed.
SpliceExperimental
A splicing iterator for VecDeque.