Module vector

Module vector 

Vec macros

Macros

into_vec
Creates a Vec from a list of elements.
vec
Creates a Vec from a list of elements.

Structs

Drain
A draining iterator for Vec<T>.
ExtractIf
An iterator which uses a closure to determine if an element should be removed.
IntoIter
An iterator that moves out of a vector.
Iter
Immutable slice iterator
IterMut
Mutable slice iterator.
Splice
A splicing iterator for Vec.
Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.
PeekMutExperimental
Structure wrapping a mutable reference to the last item in a Vec.